==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/CloudServiceNetworkProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.CloudServiceNetworkProfileArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.CloudServiceSlotType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network Profile for the cloud service.
 * @property loadBalancerConfigurations List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
 * @property slotType Slot type for the cloud service.
 * Possible values are <br /><br />**Production**<br /><br />**Staging**<br /><br />
 * If not specified, the default value is Production.
 * @property swappableCloudService The id reference of the cloud service containing the target IP with which the subject cloud service can perform a swap. This property cannot be updated once it is set. The swappable cloud service referred by this id must be present otherwise an error will be thrown.
 */
public data class CloudServiceNetworkProfileArgs(
    public val loadBalancerConfigurations: Output<List<LoadBalancerConfigurationArgs>>? = null,
    public val slotType: Output<Either<String, CloudServiceSlotType>>? = null,
    public val swappableCloudService: Output<SubResourceArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.CloudServiceNetworkProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.CloudServiceNetworkProfileArgs =
        com.pulumi.azurenative.compute.inputs.CloudServiceNetworkProfileArgs.builder()
            .loadBalancerConfigurations(
                loadBalancerConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .slotType(
                slotType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .swappableCloudService(
                swappableCloudService?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [CloudServiceNetworkProfileArgs].
 */
@PulumiTagMarker
public class CloudServiceNetworkProfileArgsBuilder internal constructor() {
    private var loadBalancerConfigurations: Output<List<LoadBalancerConfigurationArgs>>? = null

    private var slotType: Output<Either<String, CloudServiceSlotType>>? = null

    private var swappableCloudService: Output<SubResourceArgs>? = null

    /**
     * @param value List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("gupcalgrpstgnovg")
    public suspend
    fun loadBalancerConfigurations(`value`: Output<List<LoadBalancerConfigurationArgs>>) {
        this.loadBalancerConfigurations = value
    }

    @JvmName("ncuuslobdwpijsxw")
    public suspend fun loadBalancerConfigurations(
        vararg
        values: Output<LoadBalancerConfigurationArgs>,
    ) {
        this.loadBalancerConfigurations = Output.all(values.asList())
    }

    /**
     * @param values List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("nngllilfxfeteldm")
    public suspend
    fun loadBalancerConfigurations(values: List<Output<LoadBalancerConfigurationArgs>>) {
        this.loadBalancerConfigurations = Output.all(values)
    }

    /**
     * @param value Slot type for the cloud service.
     * Possible values are <br /><br />**Production**<br /><br />**Staging**<br /><br />
     * If not specified, the default value is Production.
     */
    @JvmName("mqeytefjkalgjvim")
    public suspend fun slotType(`value`: Output<Either<String, CloudServiceSlotType>>) {
        this.slotType = value
    }

    /**
     * @param value The id reference of the cloud service containing the target IP with which the subject cloud service can perform a swap. This property cannot be updated once it is set. The swappable cloud service referred by this id must be present otherwise an error will be thrown.
     */
    @JvmName("ljcackapwsatrtbe")
    public suspend fun swappableCloudService(`value`: Output<SubResourceArgs>) {
        this.swappableCloudService = value
    }

    /**
     * @param value List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("xdxlpnqxnhvfscgw")
    public suspend fun loadBalancerConfigurations(`value`: List<LoadBalancerConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadBalancerConfigurations = mapped
    }

    /**
     * @param argument List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("wwegnjbgweulfwsr")
    public suspend
    fun loadBalancerConfigurations(argument: List<suspend LoadBalancerConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            LoadBalancerConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.loadBalancerConfigurations = mapped
    }

    /**
     * @param argument List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("ieiaocwcskbejrig")
    public suspend fun loadBalancerConfigurations(
        vararg
        argument: suspend LoadBalancerConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            LoadBalancerConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.loadBalancerConfigurations = mapped
    }

    /**
     * @param argument List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("rylomjljbcxirngc")
    public suspend
    fun loadBalancerConfigurations(argument: suspend LoadBalancerConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            LoadBalancerConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.loadBalancerConfigurations = mapped
    }

    /**
     * @param values List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("lkwvbvjymptjpwuh")
    public suspend fun loadBalancerConfigurations(vararg values: LoadBalancerConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.loadBalancerConfigurations = mapped
    }

    /**
     * @param value Slot type for the cloud service.
     * Possible values are <br /><br />**Production**<br /><br />**Staging**<br /><br />
     * If not specified, the default value is Production.
     */
    @JvmName("chigfhlygvdymytq")
    public suspend fun slotType(`value`: Either<String, CloudServiceSlotType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slotType = mapped
    }

    /**
     * @param value Slot type for the cloud service.
     * Possible values are <br /><br />**Production**<br /><br />**Staging**<br /><br />
     * If not specified, the default value is Production.
     */
    @JvmName("ayisturuqsefpvod")
    public fun slotType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, CloudServiceSlotType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.slotType = mapped
    }

    /**
     * @param value Slot type for the cloud service.
     * Possible values are <br /><br />**Production**<br /><br />**Staging**<br /><br />
     * If not specified, the default value is Production.
     */
    @JvmName("lbhrvovsetvqkegg")
    public fun slotType(`value`: CloudServiceSlotType) {
        val toBeMapped = Either.ofRight<String, CloudServiceSlotType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.slotType = mapped
    }

    /**
     * @param value The id reference of the cloud service containing the target IP with which the subject cloud service can perform a swap. This property cannot be updated once it is set. The swappable cloud service referred by this id must be present otherwise an error will be thrown.
     */
    @JvmName("rygyvtpahhanchbu")
    public suspend fun swappableCloudService(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.swappableCloudService = mapped
    }

    /**
     * @param argument The id reference of the cloud service containing the target IP with which the subject cloud service can perform a swap. This property cannot be updated once it is set. The swappable cloud service referred by this id must be present otherwise an error will be thrown.
     */
    @JvmName("lojfjsekuhudtpce")
    public suspend fun swappableCloudService(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.swappableCloudService = mapped
    }

    internal fun build(): CloudServiceNetworkProfileArgs = CloudServiceNetworkProfileArgs(
        loadBalancerConfigurations = loadBalancerConfigurations,
        slotType = slotType,
        swappableCloudService = swappableCloudService,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/CloudServiceNetworkProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.CloudServiceNetworkProfileArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.CloudServiceSlotType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network Profile for the cloud service.
 * @property loadBalancerConfigurations List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
 * @property slotType Slot type for the cloud service.
 * Possible values are <br /><br />**Production**<br /><br />**Staging**<br /><br />
 * If not specified, the default value is Production.
 * @property swappableCloudService The id reference of the cloud service containing the target IP with which the subject cloud service can perform a swap. This property cannot be updated once it is set. The swappable cloud service referred by this id must be present otherwise an error will be thrown.
 */
public data class CloudServiceNetworkProfileArgs(
    public val loadBalancerConfigurations: Output<List<LoadBalancerConfigurationArgs>>? = null,
    public val slotType: Output<Either<String, CloudServiceSlotType>>? = null,
    public val swappableCloudService: Output<SubResourceArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.CloudServiceNetworkProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.CloudServiceNetworkProfileArgs =
        com.pulumi.azurenative.compute.inputs.CloudServiceNetworkProfileArgs.builder()
            .loadBalancerConfigurations(
                loadBalancerConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .slotType(
                slotType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .swappableCloudService(
                swappableCloudService?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [CloudServiceNetworkProfileArgs].
 */
@PulumiTagMarker
public class CloudServiceNetworkProfileArgsBuilder internal constructor() {
    private var loadBalancerConfigurations: Output<List<LoadBalancerConfigurationArgs>>? = null

    private var slotType: Output<Either<String, CloudServiceSlotType>>? = null

    private var swappableCloudService: Output<SubResourceArgs>? = null

    /**
     * @param value List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("jruffxmjygoqxksb")
    public suspend
    fun loadBalancerConfigurations(`value`: Output<List<LoadBalancerConfigurationArgs>>) {
        this.loadBalancerConfigurations = value
    }

    @JvmName("uccixvtmflfqonld")
    public suspend fun loadBalancerConfigurations(
        vararg
        values: Output<LoadBalancerConfigurationArgs>,
    ) {
        this.loadBalancerConfigurations = Output.all(values.asList())
    }

    /**
     * @param values List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("cmjsghexghtcbult")
    public suspend
    fun loadBalancerConfigurations(values: List<Output<LoadBalancerConfigurationArgs>>) {
        this.loadBalancerConfigurations = Output.all(values)
    }

    /**
     * @param value Slot type for the cloud service.
     * Possible values are <br /><br />**Production**<br /><br />**Staging**<br /><br />
     * If not specified, the default value is Production.
     */
    @JvmName("bqujowftswxfesey")
    public suspend fun slotType(`value`: Output<Either<String, CloudServiceSlotType>>) {
        this.slotType = value
    }

    /**
     * @param value The id reference of the cloud service containing the target IP with which the subject cloud service can perform a swap. This property cannot be updated once it is set. The swappable cloud service referred by this id must be present otherwise an error will be thrown.
     */
    @JvmName("fxqvolsbswdsjwus")
    public suspend fun swappableCloudService(`value`: Output<SubResourceArgs>) {
        this.swappableCloudService = value
    }

    /**
     * @param value List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("iqkqxsriekyphsni")
    public suspend fun loadBalancerConfigurations(`value`: List<LoadBalancerConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadBalancerConfigurations = mapped
    }

    /**
     * @param argument List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("qhrjrisbsqjctleo")
    public suspend
    fun loadBalancerConfigurations(argument: List<suspend LoadBalancerConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            LoadBalancerConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.loadBalancerConfigurations = mapped
    }

    /**
     * @param argument List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("sekgrkvjddniyojo")
    public suspend fun loadBalancerConfigurations(
        vararg
        argument: suspend LoadBalancerConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            LoadBalancerConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.loadBalancerConfigurations = mapped
    }

    /**
     * @param argument List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("rjwjlxasxnfbupia")
    public suspend
    fun loadBalancerConfigurations(argument: suspend LoadBalancerConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            LoadBalancerConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.loadBalancerConfigurations = mapped
    }

    /**
     * @param values List of Load balancer configurations. Cloud service can have up to two load balancer configurations, corresponding to a Public Load Balancer and an Internal Load Balancer.
     */
    @JvmName("dafqsoglmohyhuyd")
    public suspend fun loadBalancerConfigurations(vararg values: LoadBalancerConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.loadBalancerConfigurations = mapped
    }

    /**
     * @param value Slot type for the cloud service.
     * Possible values are <br /><br />**Production**<br /><br />**Staging**<br /><br />
     * If not specified, the default value is Production.
     */
    @JvmName("rlsdcvoywtgdljbo")
    public suspend fun slotType(`value`: Either<String, CloudServiceSlotType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slotType = mapped
    }

    /**
     * @param value Slot type for the cloud service.
     * Possible values are <br /><br />**Production**<br /><br />**Staging**<br /><br />
     * If not specified, the default value is Production.
     */
    @JvmName("ypmeoclknetwtabx")
    public fun slotType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, CloudServiceSlotType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.slotType = mapped
    }

    /**
     * @param value Slot type for the cloud service.
     * Possible values are <br /><br />**Production**<br /><br />**Staging**<br /><br />
     * If not specified, the default value is Production.
     */
    @JvmName("haopwkyascvijbsu")
    public fun slotType(`value`: CloudServiceSlotType) {
        val toBeMapped = Either.ofRight<String, CloudServiceSlotType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.slotType = mapped
    }

    /**
     * @param value The id reference of the cloud service containing the target IP with which the subject cloud service can perform a swap. This property cannot be updated once it is set. The swappable cloud service referred by this id must be present otherwise an error will be thrown.
     */
    @JvmName("genhywgvwnqggwgn")
    public suspend fun swappableCloudService(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.swappableCloudService = mapped
    }

    /**
     * @param argument The id reference of the cloud service containing the target IP with which the subject cloud service can perform a swap. This property cannot be updated once it is set. The swappable cloud service referred by this id must be present otherwise an error will be thrown.
     */
    @JvmName("egpaqeqtmgimgtqy")
    public suspend fun swappableCloudService(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.swappableCloudService = mapped
    }

    internal fun build(): CloudServiceNetworkProfileArgs = CloudServiceNetworkProfileArgs(
        loadBalancerConfigurations = loadBalancerConfigurations,
        slotType = slotType,
        swappableCloudService = swappableCloudService,
    )
}
